function [ bool ] = mydist( x,y,r,f,px,py, dir )
%MYDIST predicate that returns true iff the point (px,py) inside the elipse
%   (x,y) - center of the elipse.
%   dir - direction to which the elipse leans. can be NaN. in this case
%   circle will be used.
%   r - radius of the elipse.
%   f - focal distance of the elipse.
%   (px,py) - the point that could be inside the elipse.

    if isnan(dir) % if no directino was detected, we'll look at circels.
        center1 = [x,y];
        center2 = [x,y];
    else
        temp = tan(dir) ^ 2;
        temp = 1 / (1 + temp);
        dirX = sqrt(temp) .* f;
        dirY = sqrt(1-temp) .* f;
        center1 = [x+dirX, y+dirY];
        center2 = [x-dirX, y-dirY];
    end

    d1 =  (center1(1)-px)^2 + (center1(2)-py)^2;
    d1 = sqrt(d1);
    d2 =  (center2(1)-px)^2 + (center2(2)-py)^2;
    d2 = sqrt(d2);
    bool = ((d1 + d2) <= r);

end

