function [ fe ] = proximityFilter( r, f, e, ue)
% PROXIMITYFILTER proximity based edge detector
%   Filter edge map "e" based on the user input "ue".
%   e - edge map.
%   ue - user input.
%   r - radius of the elipse used by the filter.
%   f - focal distance of the elipse.

	a = ceil(r/2);
	b = ceil(0.5*sqrt(r^2 - f^2));
	maxab = max(a,b);
	fe = zeros(size(e));
    k0  = [0,0,0;1,1,1;0,0,0] ./ 3;
    k45 = [0,0,1;0,1,0;1,0,0] ./ 3;
    k90 = [0,1,0;0,1,0;0,1,0] ./ 3;
    k135= [1,0,0;0,1,0;0,0,1] ./ 3;

	for uei = 2:size(ue,1)-1
		for uej = 2:size(ue,2)-1
            if ue(uei,uej) == 0
                continue;
            end
            
            window = double(ue(uei-1:uei+1,uej-1:uej+1) > 0);
            if conv2(window,k0,'valid') >= 1
                dir = 0;
            elseif conv2(window,k90,'valid') >= 1
                dir = pi / 2;
            elseif conv2(window,k45,'valid') >= 1
                dir = pi / 4;
            elseif conv2(window,k135,'valid') >= 1
                dir = (3*pi)/4;
            else
                dir = NaN;
            end
            
			for ei = max(uei-maxab,1):min(uei+maxab,size(e,1))
				for ej = max(uej-maxab,1):min(uej+maxab,size(e,2))
                    if e(ei, ej) == 0
						 continue;
                    end
                    
                    if mydist(uei, uej, r, f, ei, ej, dir)
                        fe(ei,ej) = e(ei,ej);
                    end
                    
					
				end
			end
		end
	end


end

